Residual Value to Paid-In Capital (RVPI) is a term used to measure the residual
value (NAV) of a private equity fund as a multiple of the capital paid in by the
investors. The residual value is the current fair value of all assets held by
the fund and the paid-in capital by the investors is the total of all
contributed capital up to that time.

Formula: Residual Value / Paid-In Capital

See also:
- <https://www.moonfare.com/glossary/residual-value-to-paid-in-capital-rvpi>
- <https://financestu.com/rvpi/>
